#ifndef MUSICBRAINZCLIENT_H
#define MUSICBRAINZCLIENT_H

#if HAVE_CONFIG_H
#include "config.h"
#endif /* HAVE_CONFIG_H */

#if HAVE_LIBMUSICBRAINZ

#include "prokyon.h"
#include "qmbmetadata.h"

#include <qstring.h>
#include <qvaluevector.h>
#include <musicbrainz/musicbrainz.h>

class MusicBrainzClient {
public:
    MusicBrainzClient();

    QValueVector<QMBMetadata> queryServer(const QString path, TRACK *track);

    ~MusicBrainzClient() {}

private:
    MusicBrainz *mB;
};

#endif /*HAVE_LIBMUSICBRAINZ*/

#endif
